==> apache-paimon-0.9.0-src.tgz: paimon-0.9.0/paimon-core/src/main/java/org/apache/paimon/mergetree/compact/aggregate/FieldIgnoreRetractAgg.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.mergetree.compact.aggregate;

/** An aggregator which ignores retraction messages. */
public class FieldIgnoreRetractAgg extends FieldAggregator {

    private final FieldAggregator aggregator;

    public FieldIgnoreRetractAgg(FieldAggregator aggregator) {
        super(aggregator.fieldType);
        this.aggregator = aggregator;
    }

    @Override
    String name() {
        return aggregator.name();
    }

    @Override
    public Object agg(Object accumulator, Object inputField) {
        return aggregator.agg(accumulator, inputField);
    }

    @Override
    public void reset() {
        aggregator.reset();
    }

    @Override
    public Object retract(Object accumulator, Object retractField) {
        return accumulator;
    }
}

==> apache-paimon-1.0.0-src.tgz: paimon-1.0.0/paimon-core/src/main/java/org/apache/paimon/mergetree/compact/aggregate/FieldIgnoreRetractAgg.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.paimon.mergetree.compact.aggregate;

/** An aggregator which ignores retraction messages. */
public class FieldIgnoreRetractAgg extends FieldAggregator {

    private static final long serialVersionUID = 1L;

    private final FieldAggregator aggregator;

    public FieldIgnoreRetractAgg(FieldAggregator aggregator) {
        super(aggregator.name, aggregator.fieldType);
        this.aggregator = aggregator;
    }

    @Override
    public Object agg(Object accumulator, Object inputField) {
        return aggregator.agg(accumulator, inputField);
    }

    @Override
    public void reset() {
        aggregator.reset();
    }

    @Override
    public Object retract(Object accumulator, Object retractField) {
        return accumulator;
    }
}
